pub struct DltChar4 { /* private fields */ }Expand description
todo use perfo ideas from https://lise-henry.github.io/articles/optimising_strings.html todo use crate ryu for float to str conversations (numtoa seems outdated)
Implementations
Sourceimpl DltChar4
impl DltChar4
Sourcepub fn from_buf(buf: &[u8]) -> DltChar4
pub fn from_buf(buf: &[u8]) -> DltChar4
convert from buffer to DltChar4 It’s assumed only printable ascii.
Anyhow no conversions are done at construction on wrong/invalid data!
[ ] todo decide whether the following should be done here already but then the orig data will be lost on export!
chars < 0x20 are represented as ‘-’ chars > 0x7e as ‘?’
pub fn as_buf(&self) -> &[u8; 4]