adlt::dlt

Struct DltMessage

pub struct DltMessage {
    pub index: DltMessageIndexType,
    pub reception_time_us: u64,
    pub ecu: DltChar4,
    pub timestamp_dms: u32,
    pub standard_header: DltStandardHeader,
    pub extended_header: Option<DltExtendedHeader>,
    pub payload: Vec<u8>,
    pub payload_text: Option<String>,
    pub lifecycle: LifecycleId,
}

Fields

index: DltMessageIndexTypereception_time_us: u64ecu: DltChar4timestamp_dms: u32standard_header: DltStandardHeaderextended_header: Option<DltExtendedHeader>payload: Vec<u8>payload_text: Option<String>lifecycle: LifecycleId

Implementations

Source

impl DltMessage

pub fn timestamp_us(&self) -> u64

pub fn reception_time(&self) -> NaiveDateTime

pub fn mcnt(&self) -> u8

pub fn mstp(&self) -> DltMessageType

return the message type based on the extended header info. If the message has no extended header Log/Fatal is used as default.

pub fn is_ctrl_request(&self) -> bool

return whether the message is a CONTROL_REQUEST message

pub fn is_ctrl_response(&self) -> bool

return whether the message is a CONTROL_RESPONSE message

pub fn noar(&self) -> u8

return number of args from extended header. Returns 0 if no ext header is avail.

pub fn is_verbose(&self) -> bool

return whether message has verbose mode (from ext header). false if no ext header.

pub fn verb_mstp_mtin(&self) -> Option<u8>

return verb_mstp_mtin field from ext header. None if no ext header

pub fn from_headers( index: DltMessageIndexType, storage_header: DltStorageHeader, standard_header: DltStandardHeader, add_header_buf: &[u8], payload: Vec<u8>, ) -> DltMessage

pub fn to_write(&self, writer: &mut impl Write) -> Result<(), Error>

write the msg to a writer as a DLT file byte stream

  • storage header
  • standard header
  • extended header
  • payload Doesn’t try to do “atomic” writes, might fail on io errors with partial writes. session_id not supported yet. Payload endian format is taken from the msg.
pub fn header_as_text_to_write<T: Write>( &self, writer: &mut T, ) -> Result<(), Error>

pub fn set_payload_text(&mut self, text: String)

overwrite the payload text

this is intended to be used by e.g. plugins to modify the payload text for now we use a 2nd variable but we could as well simply modify the payload todo think about better ways (pros/cons)

pub fn payload_as_text(&self) -> Result<String, Error>

pub fn get_testmsg_with_payload( big_endian: bool, noar: u8, payload_buf: &[u8], ) -> DltMessage

return a verbose dltmessage with the noar and payload

should only be used for testing

ECU1/APID/CTID is used

pub fn is_big_endian(&self) -> bool

pub fn apid(&self) -> Option<&DltChar4>

pub fn ctid(&self) -> Option<&DltChar4>