pub type DltMessageIndexType = u32;Expand description
Index type for DltMessage. 32bit seem somewhat limited. but we save 4bytes in ram per msg. which alone make 16gb saved for a huge dlt file with 4mrd msgs… anyhow prepare a type so that it can be easily changed later.