Module adlt::utils[][src]

Structs

options for buffer_elements. Preparing as a struct to e.g. later add optional parameter

Enums

Functions

buffers / delays the output of elements from a stream to a stream Acts like a fifo-buffer that will be filled first with options.amount elements. Once the buffer contains the amount of message any new message will be output in fifo order. On end of the stream the buffered elements will be output.

buffer and insert sorted the elements from a stream to a stream. All the elements will be inserted sorted - so considered with the comparison at time of inserting. Once the buffer amount is filled the first (smallest) element will be output.